@@ -4,9 +4,10 @@
 #ifndef CHEMFILES_ATOM_HPP
 #define CHEMFILES_ATOM_HPP
 
+#include <cstdint>
 #include <string>
 
-#include "chemfiles/exports.hpp"
+#include "chemfiles/exports.h"
 #include "chemfiles/Property.hpp"
 #include "chemfiles/external/optional.hpp"
 
@@ -31,7 +32,7 @@ public:
     /// the matching value. This check is executed with case-insensitive atom
     /// type: `Na`, `NA`, `nA` and `na` all get the `Na` mass.
     ///
-    /// @example{tests/doc/atom/atom.cpp}
+    /// @example{atom/atom.cpp}
     ///
     /// @param name atomic name for the new atom
     explicit Atom(std::string name = "");
@@ -42,7 +43,7 @@ public:
     /// the matching value. This check is executed with case-insensitive atom
     /// type: `Na`, `NA`, `nA` and `na` all get the `Na` mass.
     ///
-    /// @example{tests/doc/atom/atom.cpp}
+    /// @example{atom/atom.cpp}
     ///
     /// @param name atomic name for the new atom
     /// @param type atomic type for the new atom
@@ -56,12 +57,12 @@ public:
 
     /// Get the atom name.
     ///
-    /// @example{tests/doc/atom/name.cpp}
+    /// @example{atom/name.cpp}
     const std::string& name() const { return name_; }
 
     /// Get the atom type.
     ///
-    /// @example{tests/doc/atom/type.cpp}
+    /// @example{atom/type.cpp}
     const std::string& type() const { return type_; }
 
     /// Get the atom mass.
@@ -70,7 +71,7 @@ public:
     /// To change the default value for a given type, you can use configuration
     /// files.
     ///
-    /// @example{tests/doc/atom/mass.cpp}
+    /// @example{atom/mass.cpp}
     double mass() const { return mass_; }
 
     /// Get the atom charge.
@@ -79,27 +80,27 @@ public:
     /// type (usually to 0). To change the default value for a given type, you
     /// can use configuration files.
     ///
-    /// @example{tests/doc/atom/charge.cpp}
+    /// @example{atom/charge.cpp}
     double charge() const { return charge_; }
 
     /// Set the atom name to `name`.
     ///
-    /// @example{tests/doc/atom/name.cpp}
+    /// @example{atom/name.cpp}
     void set_name(std::string name) { name_ = std::move(name); }
 
     /// Set the atom type to `type`.
     ///
-    /// @example{tests/doc/atom/type.cpp}
+    /// @example{atom/type.cpp}
     void set_type(std::string type) { type_ = std::move(type); }
 
     /// Set the atom mass to `mass`.
     ///
-    /// @example{tests/doc/atom/mass.cpp}
+    /// @example{atom/mass.cpp}
     void set_mass(double mass) { mass_ = mass; }
 
     /// Set the atom charge to `charge`.
     ///
-    /// @example{tests/doc/atom/mass.cpp}
+    /// @example{atom/mass.cpp}
     void set_charge(double charge) { charge_ = charge; }
 
     /// Try to get the full atomic name from the atom type.
@@ -111,11 +112,7 @@ public:
     /// `Na` full name. To change the value returned for a given type, you can
     /// use configuration files.
     ///
-    /// @verbatim embed:rst:leading-slashes This function returns an
-    /// :cpp:class:`chemfiles::optional` value that is close to C++17
-    /// ``std::optional``.  @endverbatim
-    ///
-    /// @example{tests/doc/atom/full_name.cpp}
+    /// @example{atom/full_name.cpp}
     optional<std::string> full_name() const;
 
     /// Try to get the Van der Waals radius from the atom type.
@@ -127,12 +124,7 @@ public:
     /// get the `Na` radius. To change the value returned for a given type, you
     /// can use configuration files.
     ///
-    /// @verbatim embed:rst:leading-slashes
-    /// This function returna an :cpp:class:`chemfiles::optional` value that is
-    /// close to C++17 ``std::optional``.
-    /// @endverbatim
-    ///
-    /// @example{tests/doc/atom/vdw_radius.cpp}
+    /// @example{atom/vdw_radius.cpp}
     optional<double> vdw_radius() const;
 
     /// Try to get the covalent radius from the atom type.
@@ -144,12 +136,7 @@ public:
     /// get the `Na` radius. To change the value returned for a given type, you
     /// can use configuration files.
     ///
-    /// @verbatim embed:rst:leading-slashes
-    /// This function returna an :cpp:class:`chemfiles::optional` value that is
-    /// close to C++17 ``std::optional``.
-    /// @endverbatim
-    ///
-    /// @example{tests/doc/atom/covalent_radius.cpp}
+    /// @example{atom/covalent_radius.cpp}
     optional<double> covalent_radius() const;
 
     /// Try to get the atomic number from the atom type.
@@ -161,18 +148,13 @@ public:
     /// all get the `Na` atomic number. To change the value returned for a given
     /// type, you can use configuration files.
     ///
-    /// @verbatim embed:rst:leading-slashes
-    /// This function returna an :cpp:class:`chemfiles::optional` value that is
-    /// close to C++17 ``std::optional``.
-    /// @endverbatim
-    ///
-    /// @example{tests/doc/atom/atomic_number.cpp}
+    /// @example{atom/atomic_number.cpp}
     optional<uint64_t> atomic_number() const;
 
     /// Get the map of properties asociated with this atom. This map might be
     /// iterated over to list the properties of the atom, or directly accessed.
     ///
-    /// @example{tests/doc/atom/properties.cpp}
+    /// @example{atom/properties.cpp}
     const property_map& properties() const {
         return properties_;
     }
@@ -181,7 +163,7 @@ public:
     /// `value`. If a property with this name already exist, it is replaced with
     /// the new value.
     ///
-    /// @example{tests/doc/atom/property.cpp}
+    /// @example{atom/property.cpp}
     void set(std::string name, Property value) {
         properties_.set(std::move(name), std::move(value));
     }
@@ -191,12 +173,7 @@ public:
     /// If no property with the given `name` is found, this function returns
     /// `nullopt`.
     ///
-    /// @verbatim embed:rst:leading-slashes
-    /// This function returns an :cpp:class:`chemfiles::optional` value that is
-    /// close to C++17 ``std::optional``.
-    /// @endverbatim
-    ///
-    /// @example{tests/doc/atom/property.cpp}
+    /// @example{atom/property.cpp}
     optional<const Property&> get(const std::string& name) const {
         return properties_.get(name);
     }
@@ -210,12 +187,7 @@ public:
     /// If a property with the given `name` is found, but has a different kind,
     /// this function emits a warning and returns `nullopt`.
     ///
-    /// @verbatim embed:rst:leading-slashes
-    /// This function returns an :cpp:class:`chemfiles::optional` value that is
-    /// close to C++17 ``std::optional``.
-    /// @endverbatim
-    ///
-    /// @example{tests/doc/atom/property.cpp}
+    /// @example{atom/property.cpp}
     template<Property::Kind kind>
     optional<typename property_metadata<kind>::type> get(const std::string& name) const {
         return properties_.get<kind>(name);
